summaryrefslogtreecommitdiffstats
path: root/quanta/src/document.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/src/document.h')
-rw-r--r--quanta/src/document.h45
1 files changed, 23 insertions, 22 deletions
diff --git a/quanta/src/document.h b/quanta/src/document.h
index b812ddb9..975b9f31 100644
--- a/quanta/src/document.h
+++ b/quanta/src/document.h
@@ -66,12 +66,13 @@ namespace KTextEditor
class Mark;
}
-class Document : public QWidget{
+class Document : public TQWidget{
Q_OBJECT
+ TQ_OBJECT
public:
Document(KTextEditor::Document *doc,
- TQWidget *parent = 0, const char *name = 0, WFlags f=0);
+ TQWidget *tqparent = 0, const char *name = 0, WFlags f=0);
~Document();
KURL url();
@@ -85,7 +86,7 @@ public:
void replaceSelected(const TQString &s);
/** insert tag in document */
- void insertTag(const TQString &s1, const TQString &s2 = TQString::null);
+ void insertTag(const TQString &s1, const TQString &s2 = TQString());
/** Change the current tag's attributes with those from dict */
void changeTag(Tag *tag, TQDict<TQString> *dict );
/**Change the attr value of the called attrName to attrValue*/
@@ -99,11 +100,11 @@ public:
void insertText(const TQString &text, bool adjustCursor = true, bool reparse = true);
/** Recursively insert the mandatory childs of tag. Returns true if a child was
inserted.*/
- bool insertChildTags(QTag *tag, QTag* lastTag = 0L);
+ bool insertChildTags(TQTag *tag, TQTag* lastTag = 0L);
TQPoint getGlobalCursorPos();
- TQString find(const TQRegExp& rx, int sLine, int sCol, int& fbLine, int&fbCol, int &feLine, int&feCol);
- TQString findRev(const TQRegExp& rx, int sLine, int sCol, int& fbLine, int&fbCol, int &feLine, int&feCol);
+ TQString tqfind(const TQRegExp& rx, int sLine, int sCol, int& fbLine, int&fbCol, int &feLine, int&feCol);
+ TQString tqfindRev(const TQRegExp& rx, int sLine, int sCol, int& fbLine, int&fbCol, int &feLine, int&feCol);
/** Get the view of the document */
KTextEditor::View* view();
/** Get the KTextEditor::Document of the document */
@@ -118,7 +119,7 @@ public:
void createTempFile();
/** Closes and removes the temporary file. */
void closeTempFile();
- /** Returns the name of the temporary file, TQString::null if no temporary file exists. */
+ /** Returns the name of the temporary file, TQString() if no temporary file exists. */
TQString tempFileName();
/** Returns the DTD identifier for the document */
@@ -142,9 +143,9 @@ work correctly. */
void codeCompletionHintRequested();
/** Returns the dirty status. */
bool dirty() const {return m_dirty;};
- void setDirtyStatus(bool status) {m_dirty = status;};
+ void setDirtytqStatus(bool status) {m_dirty = status;};
/** Ask for user confirmation if the file was changed outside. */
- void checkDirtyStatus();
+ void checkDirtytqStatus();
/** Save the document and reset the dirty status. */
void save();
/** Save the document under a new name and calculate the new md5sum. */
@@ -158,7 +159,7 @@ work correctly. */
/** Returns the changed status since the last query. Resets changed.*/
bool hasChanged();
/** Sets the changed status.*/
- void setChanged(bool newStatus);
+ void setChanged(bool newtqStatus);
/** Paste the contents of clipboard into the document */
void paste();
@@ -169,9 +170,9 @@ work correctly. */
/** returns all the areas that are between tag and it's closing pair */
TQStringList tagAreas(const TQString &tag, bool includeCoordinates, bool skipFoundContent);
/** disable/enable the repaint of the Kate view */
void activateRepaintView(bool activation);
- bool RepaintViewActivated() {return repaintEnabled;}
+ bool RepaintViewActivated() {return tqrepaintEnabled;}
void setErrorMark(int line);
void clearErrorMarks();
@@ -187,7 +188,7 @@ work correctly. */
*/
bool openURL(const KURL& url);
/** Reads the DTD info from the file, tries to find the correct DTD and builds the tag/attribute list from the DTD file. */
- void processDTD(const TQString& documentType = TQString::null);
+ void processDTD(const TQString& documentType = TQString());
/** Resets the list of DTEPs found in the document */
void resetDTEPs();
@@ -211,7 +212,7 @@ work correctly. */
KTextEditor::MarkInterface* markIf;
/** Hold the list of user tags (real or not, like functions) that are in the document*/
- QTagList userTagList;
+ TQTagList userTagList;
/** The undo/redo stack */
undoRedo *docUndoRedo;
@@ -228,8 +229,8 @@ work correctly. */
static TQString hashFilePath(const TQString& p);
TQString annotationText(uint line);
void setAnnotationText(uint line, const TQString& text);
- TQMap<uint, QPair<TQString, TQString> > annotations() {return m_annotations;}
- void addAnnotation(uint line, const QPair<TQString, TQString>& annotation);
+ TQMap<uint, TQPair<TQString, TQString> > annotations() {return m_annotations;}
+ void addAnnotation(uint line, const TQPair<TQString, TQString>& annotation);
void clearAnnotations();
public slots:
@@ -259,7 +260,7 @@ signals:
void breakpointMarked(Document*, int);
void breakpointUnmarked(Document*, int);
- void showAnnotation(uint, const TQString&, const QPair<TQString, TQString>&);
+ void showAnnotation(uint, const TQString&, const TQPair<TQString, TQString>&);
private slots:
void slotReplaceChar();
@@ -280,7 +281,7 @@ private:
- TQMap<uint, QPair<TQString, TQString> > m_annotations;
+ TQMap<uint, TQPair<TQString, TQString> > m_annotations;
TQString untitledUrl;
int m_replaceLine;
int m_replaceCol;
@@ -306,7 +307,7 @@ private:
bool argHintVisible;
bool hintRequested;
bool reparseEnabled;
- bool repaintEnabled;
+ bool tqrepaintEnabled;
bool delayedTextChangedEnabled;
/** True if the document is dirty (has been modified outside). */
bool m_dirty;
@@ -326,11 +327,11 @@ private:
/** Get list of possibile tag name completions */
TQValueList<KTextEditor::CompletionEntry>* getTagCompletions(int line, int col);
/** Get list of possibile tag attribute completions */
- TQValueList<KTextEditor::CompletionEntry>* getAttributeCompletions(const TQString& tagName,const TQString& startsWith=TQString::null);
+ TQValueList<KTextEditor::CompletionEntry>* getAttributeCompletions(const TQString& tagName,const TQString& startsWith=TQString());
/** Get list of possibile tag attribute value completions */
- TQValueList<KTextEditor::CompletionEntry>* getAttributeValueCompletions(const TQString& tagName, const TQString& attribute, const TQString& startsWith=TQString::null);
+ TQValueList<KTextEditor::CompletionEntry>* getAttributeValueCompletions(const TQString& tagName, const TQString& attribute, const TQString& startsWith=TQString());
/** Get list of possibile completions in normal text input (nt creating a tag) */
- TQValueList<KTextEditor::CompletionEntry>* getCharacterCompletions(const TQString& starstWith=TQString::null);
+ TQValueList<KTextEditor::CompletionEntry>* getCharacterCompletions(const TQString& starstWith=TQString());
/** Invoke code completion dialog for XML like tags according to the position (line, col), using DTD dtd. */
bool xmlCodeCompletion(int line, int col);
/** Returns list of values for attribute. If deleteResult is true after the call,
@@ -169,9 +170,9 @@ work correctly. */
/** returns all the areas that are between tag and it's closing pair */
TQStringList tagAreas(const TQString &tag, bool includeCoordinates, bool skipFoundContent);
- /** disable/enable the repaint of the Kate view */
+ /** disable/enable the tqrepaint of the Kate view */
void activateRepaintView(bool activation);